@@ -44,10 +44,10 @@ re_short_url = re.compile(r"""
 # match a bitly-ish shorturl in text
 re_short_url_text = re.compile(r"""                   
    (                      # start group
-    (https?://)?          # optional scheme
+    (https?://)           # scheme
     ([a-z1-9]+\.)?        # optional sub domain
     [a-z1-9]+.[a-z1-9]+/  # required domain
-    [a-z1-9]{5,9}         # six-ish digit hash
+    [a-z1-9]{5,12}        # six-ish digit hash
   )                       # end group
 """, re.VERBOSE | re.IGNORECASE)
 
